@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -33,14 +33,16 @@ Crypt::Password::Util - Crypt password utilities
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
  use Crypt::Password::Util qw(looks_like_crypt);
- say looks_like_crypt('$6$4DdvgCFk$...');            # 1
- say looks_like_crypt('$1$$GmbL3iXOMZR57QuGDLv.L1'); # 1
- say looks_like_crypt('foo');                        # 0
+
+ say looks_like_crypt('$1$$...');               # 1
+ say looks_like_crypt('$apr1$4DdvgCFk$...');    # 1
+ say looks_like_crypt('$6$4DdvgCFk$...');       # 1
+ say looks_like_crypt('foo');                   # 0
 
 =head1 FUNCTIONS
 
